pub enum FilterError {
InvalidPattern {
pattern: String,
reason: String,
},
InvalidPatternHint(String),
UnknownAlias(String),
}Expand description
Error returned by Filter::new.
Variants
InvalidPattern
The pattern is not a valid glob.
InvalidPatternHint(String)
A bare word that looks like a language name was used instead of a glob or alias.
UnknownAlias(String)
An @alias name is not defined.